Class: AX::Button

Inherits:
Element show all
Defined in:
lib/ax/button.rb

Overview

A generic push button and the base class for most, but not all, other buttons, including close buttons and sort buttons, but not including pop-up buttons or radio buttons.

Instance Method Summary collapse

Methods inherited from Element

#actions, #ancestor, #application, #attribute, #attributes, #blank?, #bounds, #children, #description, #initialize, #inspect, #method_missing, #methods, #notifs, #on_notification, #parameterized_attributes, #perform, #pid, #respond_to?, #search, #set, #size_of, #to_point, #to_s, #unregister_all, #unregister_notification, #writable?

Methods included from Accessibility::Factory

#process

Methods included from Accessibility::PPInspector

#pp_checkbox, #pp_children, #pp_identifier, #pp_position

Constructor Details

This class inherits a constructor from AX::Element

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class AX::Element

Instance Method Details

#==(other) ⇒ Boolean

Test equality with another object. Equality can be with another Element or it can be with a string that matches the title of the button.

Returns:

  • (Boolean)


15
16
17
18
# File 'lib/ax/button.rb', line 15

def == other
  return super unless other.kind_of? NSString
  return attribute(:title) == other
end