Class: AX::StaticText

Inherits:
Element show all
Defined in:
lib/ax/static_text.rb

Overview

Represents text on the screen that cannot directly be changed by a user, usually a label or an instructional text block.

Instance Method Summary collapse

Methods inherited from Element

#actions, #ancestor, #application, #attribute, #attributes, #blank?, #bounds, #children, #description, #initialize, #inspect, #method_missing, #methods, #notifs, #on_notification, #parameterized_attributes, #perform, #pid, #respond_to?, #search, #set, #size_of, #to_point, #to_s, #unregister_all, #unregister_notification, #writable?

Methods included from Accessibility::Factory

#process

Methods included from Accessibility::PPInspector

#pp_checkbox, #pp_children, #pp_identifier, #pp_position

Constructor Details

This class inherits a constructor from AX::Element

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class AX::Element

Instance Method Details

#==(other) ⇒ Boolean

Test equality with another object. Equality can be with another Element or it can be with a string that matches the value of the static text.

Returns:

  • (Boolean)


14
15
16
17
# File 'lib/ax/static_text.rb', line 14

def == other
  return super unless other.kind_of? NSString
  return attribute(:value) == other
end