Method: AX::SystemWide#type

Defined in:
lib/ax/systemwide.rb

#type(string) ⇒ Boolean

Note:

With the SystemWide class, using #type will send the events to which ever app has focus.

Generate keyboard events by simulating keyboard input.

See the Keyboard documentation for more information on how to format strings.

Returns:

  • (Boolean)


30
31
32
33
# File 'lib/ax/systemwide.rb', line 30

def type string
  @ref.post keyboard_events_for string
  true
end